summaryrefslogtreecommitdiffstats
path: root/win/tkWinMenu.c
diff options
context:
space:
mode:
authormdejong <mdejong>2003-04-15 01:06:08 (GMT)
committermdejong <mdejong>2003-04-15 01:06:08 (GMT)
commit2d0a4c1eb1b39e341cb8df0f7c0e0518c2623085 (patch)
treebd699be1f9b7ebb77e804c994aab8ada23a678b4 /win/tkWinMenu.c
parentc0eda27e6633bfc5790cbb82bb8684a4a3d13abf (diff)
downloadtk-2d0a4c1eb1b39e341cb8df0f7c0e0518c2623085.zip
tk-2d0a4c1eb1b39e341cb8df0f7c0e0518c2623085.tar.gz
tk-2d0a4c1eb1b39e341cb8df0f7c0e0518c2623085.tar.bz2
* win/tkWinMenu.c (TkpInitializeMenuBindings):
Rename the private menu helper cmd from tk::tkWinMenuKey to tk::WinMenuKey. [Bug 721514]
Diffstat (limited to 'win/tkWinMenu.c')
-rw-r--r--win/tkWinMenu.c22
1 files changed, 11 insertions, 11 deletions
diff --git a/win/tkWinMenu.c b/win/tkWinMenu.c
index 295a71e..696fe8d 100644
--- a/win/tkWinMenu.c
+++ b/win/tkWinMenu.c
@@ -9,7 +9,7 @@
* See the file "license.terms" for information on usage and redistribution
* of this file, and for a DISCLAIMER OF ALL WARRANTIES.
*
- * RCS: @(#) $Id: tkWinMenu.c,v 1.22 2003/04/14 23:34:50 mdejong Exp $
+ * RCS: @(#) $Id: tkWinMenu.c,v 1.23 2003/04/15 01:06:09 mdejong Exp $
*/
#define OEMRESOURCE
@@ -1744,7 +1744,7 @@ DrawMenuUnderline(
* This procedure is invoked when keys related to pulling
* down menus is pressed. The corresponding Windows events
* are generated and passed to DefWindowProc if appropriate.
* This cmd is registered as tk::tkWinMenuKey in the interp.
*
* Results:
* Always returns TCL_OK.
@@ -1899,56 +1899,56 @@ TkpInitializeMenuBindings(interp, bindingTable)
* we may want to modify the binding in Tcl code.
*/
- (void) Tcl_CreateObjCommand(interp, "tk::tkWinMenuKey",
+ (void) Tcl_CreateObjCommand(interp, "tk::WinMenuKey",
TkWinMenuKeyObjCmd,
(ClientData) Tk_MainWindow(interp), (Tcl_CmdDeleteProc *) NULL);
(void) Tk_CreateBinding(interp, bindingTable,
(ClientData) uid,
"<Alt_L>",
- "tk::tkWinMenuKey %W %N",
+ "tk::WinMenuKey %W %N",
0);
(void) Tk_CreateBinding(interp, bindingTable,
(ClientData) uid,
"<KeyRelease-Alt_L>",
- "tk::tkWinMenuKey %W %N",
+ "tk::WinMenuKey %W %N",
0);
(void) Tk_CreateBinding(interp, bindingTable,
(ClientData) uid,
"<Alt_R>",
- "tk::tkWinMenuKey %W %N",
+ "tk::WinMenuKey %W %N",
0);
(void) Tk_CreateBinding(interp, bindingTable,
(ClientData) uid,
"<KeyRelease-Alt_R>",
- "tk::tkWinMenuKey %W %N",
+ "tk::WinMenuKey %W %N",
0);
(void) Tk_CreateBinding(interp, bindingTable,
(ClientData) uid,
"<Alt-KeyPress>",
- "tk::tkWinMenuKey %W %N",
+ "tk::WinMenuKey %W %N",
0);
(void) Tk_CreateBinding(interp, bindingTable,
(ClientData) uid,
"<Alt-KeyRelease>",
- "tk::tkWinMenuKey %W %N",
+ "tk::WinMenuKey %W %N",
0);
(void) Tk_CreateBinding(interp, bindingTable,
(ClientData) uid,
"<KeyPress-F10>",
- "tk::tkWinMenuKey %W %N",
+ "tk::WinMenuKey %W %N",
0);
(void) Tk_CreateBinding(interp, bindingTable,
(ClientData) uid,
"<KeyRelease-F10>",
- "tk::tkWinMenuKey %W %N",
+ "tk::WinMenuKey %W %N",
0);
}
@@ -1744,7 +1744,7 @@ DrawMenuUnderline(
* down menus is pressed. The corresponding Windows events
* are generated and passed to DefWindowProc if appropriate.
- * This cmd is registered as tk::tkWinMenuKey in the interp.
+ * This cmd is registered as tk::WinMenuKey in the interp.
*
* Results: